#include "CmdWakePin.h"

CmdWakePin::CmdWakePin() :
#if MTS_CMD_TERM_VERBOSE
    Command("Wake Pin", "AT+WP", "Wakeup DIO pin of sleep mode (1-8) (default: DI8, 1:DIN), deep-sleep uses DIO7", "(1-8)")
#else
    Command("AT+WP")
#endif
{
    _queryable = true;
}

uint32_t CmdWakePin::action(const std::vector<std::string>& args) {
    if (args.size() == 1) {
        CommandTerminal::Serial()->writef("%s\r\n", mDot::pinName2Str(CommandTerminal::Dot()->getWakePin()).c_str());
    } else if (args.size() == 2) {
        int pin;
        sscanf(args[1].c_str(), "%d", &pin);

        CommandTerminal::Dot()->setWakePin(mDot::pinNum2Name(pin));
    }

    return 0;
}

bool CmdWakePin::verify(const std::vector<std::string>& args) {
    if (args.size() == 1)
        return true;

    if (args.size() == 2) {
        int pin;
        if (sscanf(args[1].c_str(), "%d", &pin) != 1) {
#if MTS_CMD_TERM_VERBOSE
            CommandTerminal::setErrorMessage("Invalid argument");
#endif
            return false;
        }

#if defined(TARGET_MTS_MDOT_F411RE)
        if (pin < 1 || pin > 8) {
#if MTS_CMD_TERM_VERBOSE
            CommandTerminal::setErrorMessage("Invalid pin, expects (1-8)");
#endif
#else
        if (pin < 1 || pin > 6) {
#if MTS_CMD_TERM_VERBOSE
            CommandTerminal::setErrorMessage("Invalid pin, expects (1-6)");
#endif
#endif /* TARGET_MTS_MDOT_F411RE */
            return false;
        }

        return true;
    }

#if MTS_CMD_TERM_VERBOSE
    CommandTerminal::setErrorMessage("Invalid arguments");
#endif
    return false;
}
